QueryBuilder

Struct QueryBuilder 

pub struct QueryBuilder<'a, Output, T: Display, G: HasGraphSchema> { /* private fields */ }
A Builder-pattern struct that allows creating and executing queries on a graph

Implementations

Source

impl<'a, Output, T: Display, G: HasGraphSchema> QueryBuilder<'a, Output, T, G>

pub fn with_params(self, params: &'a HashMap<String, String>) -> Self

Pass the following params to the query as “CYPHER {param_key}={param_val}”

Arguments
  • params: A HashMap of params in key-val format
pub fn with_timeout(self, timeout: i64) -> Self

Specify a timeout after which to abort the query

Arguments
  • timeout: the timeout after which the server is allowed to abort or throw this request, in milliseconds, when that happens the server will return a timeout error
Source

impl<'a, T: Display> QueryBuilder<'a, QueryResult<LazyResultSet<'a>>, T, SyncGraph>

pub fn execute(self) -> FalkorResult<QueryResult<LazyResultSet<'a>>>

Executes the query, retuning a QueryResult, with a LazyResultSet as its data member

Source

impl<'a, T: Display> QueryBuilder<'a, QueryResult<LazyResultSet<'a>>, T, AsyncGraph>

pub async fn execute(self) -> FalkorResult<QueryResult<LazyResultSet<'a>>>

Executes the query, retuning a QueryResult, with a LazyResultSet as its data member

Source

impl<T: Display> QueryBuilder<'_, ExecutionPlan, T, SyncGraph>

pub fn execute(self) -> FalkorResult<ExecutionPlan>

Executes the query, returning an ExecutionPlan from the data returned

Source

impl<'a, T: Display> QueryBuilder<'a, ExecutionPlan, T, AsyncGraph>

pub async fn execute(self) -> FalkorResult<ExecutionPlan>

Executes the query, returning an ExecutionPlan from the data returned