pub struct QueryBuilder<'a, Output, T: Display, G: HasGraphSchema> { /* private fields */ }Expand description
A Builder-pattern struct that allows creating and executing queries on a graph
Implementations
Sourceimpl<'a, Output, T: Display, G: HasGraphSchema> QueryBuilder<'a, Output, T, G>
impl<'a, Output, T: Display, G: HasGraphSchema> QueryBuilder<'a, Output, T, G>
Sourcepub fn with_params(self, params: &'a HashMap<String, String>) -> Self
pub fn with_params(self, params: &'a HashMap<String, String>) -> Self
Sourcepub fn with_timeout(self, timeout: i64) -> Self
pub fn with_timeout(self, timeout: i64) -> Self
Specify a timeout after which to abort the query
Arguments
timeout: the timeout after which the server is allowed to abort or throw this request, in milliseconds, when that happens the server will return a timeout error
Sourceimpl<'a, T: Display> QueryBuilder<'a, QueryResult<LazyResultSet<'a>>, T, SyncGraph>
impl<'a, T: Display> QueryBuilder<'a, QueryResult<LazyResultSet<'a>>, T, SyncGraph>
Sourcepub fn execute(self) -> FalkorResult<QueryResult<LazyResultSet<'a>>>
pub fn execute(self) -> FalkorResult<QueryResult<LazyResultSet<'a>>>
Executes the query, retuning a QueryResult, with a LazyResultSet as its data member
Sourceimpl<'a, T: Display> QueryBuilder<'a, QueryResult<LazyResultSet<'a>>, T, AsyncGraph>
impl<'a, T: Display> QueryBuilder<'a, QueryResult<LazyResultSet<'a>>, T, AsyncGraph>
Sourcepub async fn execute(self) -> FalkorResult<QueryResult<LazyResultSet<'a>>>
pub async fn execute(self) -> FalkorResult<QueryResult<LazyResultSet<'a>>>
Executes the query, retuning a QueryResult, with a LazyResultSet as its data member
Sourceimpl<T: Display> QueryBuilder<'_, ExecutionPlan, T, SyncGraph>
impl<T: Display> QueryBuilder<'_, ExecutionPlan, T, SyncGraph>
Sourcepub fn execute(self) -> FalkorResult<ExecutionPlan>
pub fn execute(self) -> FalkorResult<ExecutionPlan>
Executes the query, returning an ExecutionPlan from the data returned
Sourceimpl<'a, T: Display> QueryBuilder<'a, ExecutionPlan, T, AsyncGraph>
impl<'a, T: Display> QueryBuilder<'a, ExecutionPlan, T, AsyncGraph>
Sourcepub async fn execute(self) -> FalkorResult<ExecutionPlan>
pub async fn execute(self) -> FalkorResult<ExecutionPlan>
Executes the query, returning an ExecutionPlan from the data returned